@@ -2,9 +2,13 @@ library(foreign)
 pc5 <- read.dta("pc5.dta")
 summary(pc5)
 str(pc5)
+compressed<-read.dta("compressed.dta")
+summary(compressed)
+all.equal(summary(pc5), summary(compressed))
 sun6 <- read.dta("sun6.dta")
 summary(sun6)
 str(sun6)
+all.equal(summary(sun6),summary(pc5))
 df<-read.dta("datefactor.dta")
 summary(df)
 data(esoph)
@@ -20,8 +24,10 @@ all.equal(as.numeric(esoph$alcgp),as.numeric(esoph2$alcgp))
 
 se<-read.dta("stata7se.dta")
 print(se)
+v8<-read.dta("stata8mac.dta")
+print(v8)
 
-stata8<-read.dta("auto8.dta",missing=TRUE)
+stata8<-read.dta("auto8.dta",missing=TRUE,convert.underscore=FALSE)
 str(stata8)
 
 q()
